@@ -2,7 +2,7 @@ package Mojolicious::Plugin::FormChecker;
 
 use Mojo::Base 'Mojolicious::Plugin';
 
-our $VERSION = '1.001002'; # VERSION
+our $VERSION = '1.001003'; # VERSION
 
 sub register {
     my ($self, $app) = @_;
@@ -601,7 +601,7 @@ value.
     min_error => 'Too short :(',
 
 This is the error for C<min> rule. B<Defaults to:>
-C<< Parameter $name must be at least $min characters long >
+C<Parameter $name must be at least $min characters long>
 
 =head4 C<code_error>
 
